from datetime import date

import aiosql
import psycopg
from psycopg.rows import dict_row

import pytest
import run_tests as t


@pytest.fixture()
def queries():
    return t.queries("psycopg")


def test_version():
    assert psycopg.__version__.startswith("3.")


def test_record_query(pg_params, queries):
    with psycopg.connect(**pg_params, row_factory=dict_row) as conn:
        t.run_record_query(conn, queries)


def test_parameterized_query(pg_conn, queries):
    t.run_parameterized_query(pg_conn, queries)


def test_parameterized_record_query(pg_params, queries):
    with psycopg.connect(**pg_params, row_factory=dict_row) as conn:
        t.run_parameterized_record_query(conn, queries, "pg", date)


def test_record_class_query(pg_conn, queries):
    t.run_record_class_query(pg_conn, queries, date)


def test_select_cursor_context_manager(pg_conn, queries):
    t.run_select_cursor_context_manager(pg_conn, queries, date)


def test_select_one(pg_conn, queries):
    t.run_select_one(pg_conn, queries)


def test_select_value(pg_conn, queries):
    t.run_select_value(pg_conn, queries)


def test_modulo(pg_conn, queries):
    actual = queries.blogs.pg_get_modulo(pg_conn, left=7, right=3)
    expected = 7 % 3
    assert actual == expected


def test_insert_returning(pg_conn, queries):
    t.run_insert_returning(pg_conn, queries, "pg", date)


def test_delete(pg_conn, queries):
    t.run_delete(pg_conn, queries)


def test_insert_many(pg_conn, queries):
    with pg_conn:
        t.run_insert_many(pg_conn, queries, date)
